import { Grid, TextField } from "@mui/material";
import { useEffect, useState } from "react";
import { useDispatch } from "react-redux";
import { setNewTasksForCells } from "../../store/actions/tasksActions";

function MonthCalendarBody({month, year, tasks, createTaskInCellHandler}) {
  
  const [hoursInDay, setHoursInDay] = useState(['8:00', '10:00', '12:00', '14:00', '16:00', '18:00', '20:00', '22:00', '6:00'])
  const [daysInMonth, setDaysInMonth] = useState([])

  useEffect(()=>{
    setNewMonthDays()
  }, [month, year])

  const getDaysInMonth = () => { 
    return new Date(year, month + 1, 0).getDate();
  }

  const getDayOfWeekString = (day) => {
    return ["ВС","ПН","ВТ","СР","ЧТ","ПТ","СБ"][day];
  }

  const getDayOfWeekNumber = (day) => {
    return new Date(year, month, day).getDay()
  }

  const setNewMonthDays = () => {
    const newDaysInMonth = []
    for (let i = 1; i <= getDaysInMonth(); i++) {
      const dayOfWeekNumber = getDayOfWeekNumber(i)
      newDaysInMonth.push({dayNumber: i, dayOfWeek: getDayOfWeekString(dayOfWeekNumber)})
    }
    setDaysInMonth(newDaysInMonth)
  }

  const getTaskInDayCell = (tasks, day, hours) => {
    const task = tasks.find(task=> {
    if (year === task.infoForCell.startYear) {
      if (month + 1 === task.infoForCell.startMonth) {
        if (day.dayNumber === task.infoForCell.startDay && task.infoForCell.startDayOfWeek === day.dayOfWeek ) {
          if ((task.infoForCell.endHour <= parseInt(hours.split(':')[0]) || task.infoForCell.startHour <= parseInt(hours.split(':')[0])) && (task.infoForCell.endHour >= parseInt(hours.split(':')[0]))) {
            return task
          }
        }
      }      
    }
    })
    return task
  }
  
  const onChangeCellTaskTitle = (e, task) => {
    const value = e.target.value;
    const name = e.target.name;
    const { id } = task;
    const newTasks =  tasks.map(task => {
      if (task.id === id) {
        return { ...task, [name]: value };
      }
      return task;
    });
    setNewTasksForCells(newTasks)
  }

  return (
    <>
    <Grid
      container
      align='center'
      sx={{borderBottom: '1px solid black', borderRight: '1px solid black', borderLeft: '1px solid black'}}
      >
        <Grid align='center' item xs={0.5} sx={{borderRight: '1px solid black'}}>
          {' '}
        </Grid>
        <Grid align='center' item xs={0.5} sx={{borderRight: '1px solid black'}}>
          {' '}
        </Grid>
        {hoursInDay.map((hours, i)=>{
          return (
            <Grid key={i} item xs={1.2222} sx={{borderRight: '1px solid black'}}>
              {hours}
            </Grid>
            ) 
          })}
    </Grid>
    {daysInMonth.map((day, i)=>{
      return (
        <Grid 
          key={i}
          container 
          align='center'
          sx={{borderBottom: '1px solid black', borderRight: '1px solid black', borderLeft: '1px solid black'}}
          >
            <Grid align='center' item xs={0.5} sx={{borderRight: '1px solid black'}}>
              {day.dayNumber}
            </Grid>
            <Grid align='center' item xs={0.5} sx={{borderRight: '1px solid black'}}>
              {day.dayOfWeek}
            </Grid>
            {hoursInDay.map((hours, i)=>{
              const task = getTaskInDayCell(tasks, day, hours)
              return (
                <Grid  
                  key={i} 
                  item xs={1.2222} 
                  sx={{borderRight: '1px solid black'}} 
                  onClick={()=>{createTaskInCellHandler(day.dayOfWeek, day.dayNumber, hours)}}>
                  { task ? 
                    <Grid  key={i} sx={{backgroundColor: 'lightgreen'}}>
                        <TextField 
                        id={task.title} 
                        variant="standard" 
                        value={task.title} 
                        name='title' 
                        onChange={(e)=>{onChangeCellTaskTitle(e, task)}}></TextField>
                    </Grid> : null}
                </Grid>
                ) 
              })}
        </Grid>
      )
    })}
    </>
  );
}

export default MonthCalendarBody;