import { Container } from '@mui/material';
import { useEffect, useState } from 'react';
import { useDispatch, useSelector } from 'react-redux';
import MonthCalendarBody from '../../components/MonthCalendarBody/MonthCalendarBody';
import MonthCalendarHeader from '../../components/MonthCalendarHeader/MonthCalendarHeader';
import { fetchTasks} from '../../store/actions/tasksActions';

function MonthCalendar() {
  const dispatch = useDispatch();
  const { tasks } = useSelector(state => state.tasks);

  const [month, setMonth] = useState('')
  const [year, setYear] = useState('')
  const [worker, setWorker] = useState('');
  const [calendarType, setCalendarType] = useState('Месяц');
  
  useEffect(()=>{
    setMonth(new Date().getMonth())
    setYear(new Date().getFullYear())
    dispatch(fetchTasks())
  }, [dispatch])
  console.log(tasks)
  const onChangeWorkerHandler = (event) => {
    setWorker(event.target.value);
  };

  const onChangeCalendarTypeHandler = (event) => {
    setCalendarType(event.target.value);
  };

  const getCurrentMonthString = (month) => {
    return ["Январь","Февраль","Март","Апрель","Май","Июнь","Июль","Август","Сентябрь","Октябрь","Ноябрь", "Декабрь"][month];
  }

  const incrementMonth = () => {
    setMonth((prevState)=>{
      if (prevState + 1 === 12 ) { 
        setYear(prevState=>prevState+1)
        return 0 
      }
      return prevState + 1
    })
  }

  const decrementMonth = () => {
    setMonth((prevState)=>{
      if (prevState - 1 === -1) {
        setYear(prevState=>prevState-1)
        return 11
      }
      return prevState - 1 
    })
  }

  const createTaskInCellHandler = (dayOfWeek, dayNumber, dayHour) => {
    // const newTasks = [...tasksForCell]
    // const newTask = {
    //   id: Date.now(),
    //   user:"first",
    //   title:"Новая",
    //   description:"описание задачи11111",
    //   priority:"A",
    //   author:"Ivan",
    //   executor:"Arman",
    //   dateTimeStart:`${dayNumber}.${month+1}.${year} ${parseInt(dayHour.split(':')[0])}:00:00`,
    //   dateTimeDue:`${dayNumber}.${month+1}.${year} ${parseInt(dayHour.split(':')[0]) + 1}:00:00`,
    // }
    // newTasks.push(newTask)
    // exampleTasks.push(newTask)
    // setNewTasksWithInfoForCell(newTasks)
  }

  return (
    <>
    <Container>
      <MonthCalendarHeader
        month={month}
        year={year}
        getCurrentMonthString={getCurrentMonthString} 
        decrementMonth={decrementMonth}
        incrementMonth={incrementMonth}
        onChangeCalendarTypeHandler={onChangeCalendarTypeHandler}
        onChangeWorkerHandler={onChangeWorkerHandler}
        worker={worker}
        calendarType={calendarType}
      />
      <MonthCalendarBody
        month={month}
        year={year}
        tasks={tasks}
        createTaskInCellHandler={createTaskInCellHandler}
      />
    </Container>
    </>
  );
}

export default MonthCalendar;
